pub struct Delta {
pub document_id: DocumentID,
pub fields: HashMap<FieldPath, Field>,
pub version: VectorClock,
}Expand description
Represents changes between two document states
Contains only the fields that changed, making network transmission efficient. A delta can be applied to a document to update it to a new state.
Fields
document_id: DocumentIDDocument this delta applies to
fields: HashMap<FieldPath, Field>Changed fields (only includes fields that differ)
version: VectorClockVector clock after applying this delta
Implementations
Sourceimpl Delta
impl Delta
Sourcepub fn new(
document_id: DocumentID,
fields: HashMap<FieldPath, Field>,
version: VectorClock,
) -> Self
pub fn new( document_id: DocumentID, fields: HashMap<FieldPath, Field>, version: VectorClock, ) -> Self
Create a new delta
Sourcepub fn empty(document_id: DocumentID, version: VectorClock) -> Self
pub fn empty(document_id: DocumentID, version: VectorClock) -> Self
Create an empty delta (no changes)